import os

def get_secrets(directory='/etc/secrets/'):

    secret_dict = {}

    # make sure the directory has the trailing slash
    if directory[-1] != '/':
        directory = directory + '/'

    for s_key in os.listdir(directory):
        with open(directory + s_key, 'r') as sf:
            s_value = sf.read()
            secret_dict[s_key] = s_value.strip()

    return secret_dict




from setuptools import setup, find_packages

setup(name='mystiko',
      version='0.1',
      description='Collect kubernetes secrets into a python dictionary.',
      url='http://github.com/lander2k2/mystiko',
      author='Richard Lander',
      author_email='lander2k2@gmail.com',
      license='MIT',
      packages=find_packages(),
      zip_safe=False)

